<?php

/*
 * Plugin Name: wp pear debug
 * Description: Integration of pear php_debug
 * Author: Slasco solutions
 * Plugin URI: communitymodder.com
 * Version: 1.0B2
 * =======================================================================
 */
 //create global path for plugin
define('WP_PEAR_DEBUG_PATH',WP_PLUGIN_DIR."/wp-pear-debug");
//global url for plugin
define('WP_PEAR_DEBUG_URL',WP_PLUGIN_URL."/wp-pear-debug");


//Start registering stuff
add_action('plugins_loaded',array('wp_pear_debug','init'));


class wp_pear_debug
{
	//include javascript
	public static function js()
	{
		wp_enqueue_script('debug_js', "".WP_PEAR_DEBUG_URL."/js/html_div.js"); 
	}
	//include css
	public static function css()
	{
		echo '<link rel="stylesheet" type="text/css" href="'.WP_PEAR_DEBUG_URL.'/css/html_div.css" />';
	}
	//return configuration options
	//to set a better config function in the next version
	public static function getConf($param='')
	{
		return array
		(
			'render_type'          => 'HTML',
			'render_mode'          => 'Div',
			'restrict_access'      => false,
			'allow_url_access'     => false,
			'enable_watch'         => false,
			'replace_errorhandler' => true,
			'HTML_DIV_images_path' => WP_PEAR_DEBUG_URL."/images",
		);
	}	
	//include a class file
	//neat way of loading classes relative to base folder
	public static function loadClass($sClassPath)
	{
		$aParts = explode(".",$sClassPath);
		$sFile = WP_PEAR_DEBUG_PATH."/";
		$iCount = 0;
		
		foreach($aParts as $sPart )
		{
			if( $iCount != count($aParts)-1 )
			{
				$sFile.= $sPart."/";
			}	
			else
			{			
				$sFile.= $sPart.".class.php";
				
				break;
					
			}			
			$iCount++;
		}
		
		if( file_exists($sFile) && !is_dir($sFile) )
		{
			include_once($sFile);
		}
		else
		{
			throw new Exception($sFile);
			
		}
	
	}
	//return instance of class
	public static function getClass($sClassPath)
	{
		self::loadClass($sClassPath);
		
		$aParts = explode(".",$sClassPath);
		$sClass = $aParts[count($aParts)-1];
		$oClass =  new $sClass;
		//Use exisiting instance if possible
		if(method_exists($oClass,'singleton'))
		{
			$oClass = $oClass->singleton();
			
		}
	
		return $oClass;
		
	}
	
	public static function init()
	{
		
		$sDebug = self::enabled();
	
		if($sDebug == 'admin' || $sDebug == 'both')
		{ 
			add_action('admin_head',array('wp_pear_debug','css'));
			add_action('admin_footer',array('wp_pear_debug','show'));
		}
		
		if($sDebug == 'front' || $sDebug == 'both')
		{ 
			add_action('wp_head',array('wp_pear_debug','css'));
			add_action('wp_footer',array('wp_pear_debug','show'));
		}

		if($sDebug)
		{
			//add in javascript file
			add_action('init',array('wp_pear_debug','js'));		
			//unlimited possibilities for add_filter and this plugin
			add_filter('query',array('wp_pear_debug','query'));
			//Enable shortcode debug entry point
			add_shortcode('wp_pear_debug', array('wp_pear_debug','short'));
		}
		//add options page to the admin menu
		add_action('admin_menu',array('wp_pear_debug','admin'));
	}
	//not using globals
	//use this to get single instance of debug class
	//All this drama just to load one class library!
	public static function get()	{
		
		return self::getClass('PHP_Debug');
	}
	
	public static function show()
	{
		$oDebug = self::get();
		$oDebug->display();
	}
	
	//add database query to debug
	public static function query($query)
	{
		$oDebug = self::get();
		
		$oDebug->query($query);
		return $query;
	}
	
	public static function enabled()
	{
		$u = wp_get_current_user();
		
		if( is_array($u->roles) && count($u->roles) )
		{
			$role = array_shift( $u->roles );
		}
		else
		{
			$role = 'guest';
		}
	
		//using switch because I may add more options
		switch( get_option('wp_pear_debug_status') )
		{
			case 'enable':
			switch( get_option('wp_pear_debug_'.$role) )
			{
				case 'enable':
				return 'both';
				break;
				
				case 'admin':
				return 'admin';
				break;
				
				case 'front':
				return 'front';
				break;
				
				default:
				return false;
			}
			break;
		
			default:
			return false;
		}
		

				
	}

		//wrapper functions
		//Library contains may more functions
		
		public static function add($sVar)
		{
			$oDebug = self::get();
			$oDebug->add($sVar);
			
		}
		public static function dump($obj, $varName = '')
		{
			$oDebug = self::get();
			$oDebug->dump($obj, $varName);
			
		}	
		public static function queryRel($sInfo)
		{
			$oDebug = self::get();
			$oDebug->queryRel($sInfo);
			
		}
		public static function error($sInfo)
		{
			$oDebug = self::get();
			$oDebug->error($sInfo);
			
		}
		//shortcode entry point to debug
		//Does not return anything
		//Picks up data from post content
		//Have no idea what this can be used for! lol!
		public static function short($atts,$sContent='')
		{
			
			if( isset($sContent) && !empty($sContent) )
			{
				self::add($sContent);
			}
			else
			{
				self::dump($atts);
			}
		}	


public static function admin() {

add_options_page('Debugger Options', 'Debugger', 10, '/wp-pear-debug/'.basename(__FILE__),array('wp_pear_debug','options'));
 }


public static function options()
{
	global $wpdb;

	?>
<div class=wrap>
  <form method="post" action="options.php">
  <?php wp_nonce_field('update-options'); ?>

    <h3>Debugger Settings</h3>
<div>
<table class="form-table">
<tr>
<td width="200" >
Debug Status:<strong>Overall</strong>
</td>
<td>
<select name="wp_pear_debug_status">
<option  value="enable" <?php  if(get_option('wp_pear_debug_status')=='enable') echo "selected"; ?> >Enable Debugging</option>
<option value="disable" <?php  if(get_option('wp_pear_debug_status')=='disable') echo "selected"; ?> >Disable Debugging</option>
</select>
</td>
</tr>
<td  >
Debug Debugging for: <strong>Guests</strong>
</td>
<td>
<select name="wp_pear_debug_guest">
<option  value="front" <?php  if(get_option('wp_pear_debug_guest')=='front') echo "selected"; ?> >Front End Only</option>
<option value="disable" <?php  if(get_option('wp_pear_debug_guest')=='disable') echo "selected"; ?> >Disable</option>
</select>
</td>
</tr>
<?php 
$sKeys = "";
foreach(get_option($wpdb->prefix . 'user_roles')  as $key => $value)
{
	?>
	<tr>
	<td>
Display Debug for: <strong><?php echo ucfirst($key); ?></strong>	
</td>
<td>
<select name="wp_pear_debug_<?php echo $key; ?>">	
<option value="enable" <?php  if(get_option('wp_pear_debug_'.$key)=='enable') echo "selected"; ?> >Admin & Front End</option>	
<option value="admin" <?php  if(get_option('wp_pear_debug_'.$key)=='admin') echo "selected"; ?> >Admin Only</option>	
<option value="front" <?php  if(get_option('wp_pear_debug_'.$key)=='front') echo "selected"; ?> >Front End Only</option>
<option value="disable" <?php  if(get_option('wp_pear_debug_'.$key)=='disable') echo "selected"; ?>>Disable</option>
</select>	
<?php
$sKeys.=',wp_pear_debug_'.$key."";
}
?>
</td>
</tr>
</table>
<input type="hidden" name="action" value="update" />
<input type="hidden" name="page_options" value="wp_pear_debug_guest,wp_pear_debug_status<?php echo $sKeys; ?>" />

</div>
<div class="submit">
<input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
</div>

  </form>
 </div><?php
}

	
	
}	






?>